--- kcontrol/nics/nic.cpp.orig	Thu Mar  7 19:16:42 2002
+++ kcontrol/nics/nic.cpp	Thu Mar 28 17:16:56 2002
@@ -42,6 +42,9 @@
 #include <stdio.h>
 #include <unistd.h>
 #include <sys/socket.h>
+#ifdef _AIX
+#  define IP_MULTICAST
+#endif
 #include <net/if.h>
 #include <sys/ioctl.h>
 
--- kioslave/imap4/imap4.cc.orig	Mon Apr  1 12:38:26 2002
+++ kioslave/imap4/imap4.cc	Mon Apr  1 12:38:49 2002
@@ -41,6 +41,10 @@
     imap://server/folder/ - List messages in folder
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "imap4.h"
 
 #include "rfcdecoder.h"
--- kcontrol/kcontrol/global.cpp.orig	Fri Apr 12 13:46:34 2002
+++ kcontrol/kcontrol/global.cpp	Fri Apr 12 13:55:54 2002
@@ -67,9 +67,17 @@
   uname(&info);
 
   setSystemName(info.sysname);
+
+#ifdef _AIX
+  //On AIX, the OS level is obtained as "version"."release" .
+  //Don't use "machine"--it's the CPU ID, not architecture.
+  setSystemRelease(QString::fromLatin1(info.version) + "." + QString::fromLatin1(info.release));
+  setSystemMachine("PowerPC");
+#else
   setSystemRelease(info.release);
   setSystemVersion(info.version);
   setSystemMachine(info.machine);
+#endif
 }
 
 void KCGlobal::setType(const QCString& s)
--- kdm/backend/auth.c.orig	Fri Apr 12 14:29:59 2002
+++ kdm/backend/auth.c	Fri Apr 12 14:30:13 2002
@@ -100,6 +100,10 @@
 # endif
 #endif
 
+#ifdef _AIX
+#  define VARIABLE_IFREQ
+#endif
+
 #ifdef __EMX__
 # define link rename
 int chown(int a,int b,int c) {}
--- kdm/backend/dm.c.orig	Fri Apr 12 15:31:11 2002
+++ kdm/backend/dm.c	Mon Apr 15 08:52:24 2002
@@ -486,7 +486,7 @@
 		       utp->d->name, utp->line);
 		*utpp = utp->next;
 		free (utp);
-		ExitDisplay (d, TRUE, TRUE, TRUE);
+		ExitDisplay (d, DS_RESTART, TRUE, TRUE);
 		StartDisplays ();
 		continue;
 	    }
--- kioslave/Makefile.am.orig	Tue Jun 11 12:47:32 2002
+++ kioslave/Makefile.am	Tue Jun 11 12:47:41 2002
@@ -1,4 +1,4 @@
 ## $Id: Makefile.am,v 1.49 2002/01/12 07:47:57 garbanzo Exp $
 
-SUBDIRS = floppy filter info man nfs nntp pop3 imap4 smtp \
+SUBDIRS = floppy filter info man nntp pop3 imap4 smtp \
   smbro sftp tar finger thumbnail $(LDAP_SUBDIR) $(AUDIOCD_SUBDIR) $(SMB_SUBDIR) 
--- kdm/kfrontend/genkdmconf.c.orig	Tue Sep 16 11:28:20 2003
+++ kdm/kfrontend/genkdmconf.c	Tue Sep 16 11:28:04 2003
@@ -476,18 +476,20 @@
 "	fi\n"
 "done\n"
 "\n"
-"if test -f $HOME/.xprofile; then\n"
-"    . $HOME/.xprofile\n"
-"else\n"
-"    test -f /etc/profile && . /etc/profile\n"
-"    test -f $HOME/.profile && . $HOME/.profile\n"
-"fi\n"
+"test -f /etc/profile && . /etc/profile\n"
+"test -f $HOME/.profile && . $HOME/.profile\n"
+"test -f /etc/xprofile && . /etc/xprofile\n"
+"test -f $HOME/.xprofile && . $HOME/.xprofile\n"
 "\n"
 "sess=\"$1\"\n"
 "shift\n"
 "\n"
 "case \"$sess\" in\n"
 "    failsafe)\n"
+"      aixterm -geometry 80x24-0-0 &\n"
+"      exec mwm\n"
+"      ;;\n"
+"    xterm)\n"
 "	exec xterm -geometry 80x24-0-0 $*\n"
 "	;;\n"
 "    \"\"|default)\n"
@@ -980,7 +982,7 @@
 };
 
 DEnt dEntsXdmcp[] = {
-{ "Enable",		"false", 1 },
+{ "Enable",		"true", 1 },
 { "Port",		"177", 0 },
 { "KeyFile",		"", 0 },
 { "Xaccess",		KDMCONF "/Xaccess", 1 }, /* b/c of inadequate def handling */
@@ -1040,7 +1042,7 @@
 };
 
 static DEnt dEntsAnyGreeter[] = {
-{ "SessionTypes",	"default,kde,failsafe", 1 },
+{ "SessionTypes",	"kde,gnome,CDE,failsafe,xterm", 1 },
 { "GUIStyle",		"Windows", 0 },
 { "LogoArea",		"None", 0 },
 { "LogoPixmap",		"", 0 },
@@ -1048,9 +1050,9 @@
 { "GreeterPosX",	"200", 0 },
 { "GreeterPosY",	"100", 0 },
 { "GreetString",	"K Desktop Environment (%n)", 0 },
-{ "GreetFont",		"charter,24,5,0,50,0", 0 },
-{ "StdFont",		"helvetica,12,5,0,50,0", 0 },
-{ "FailFont",		"helvetica,12,5,0,75,0", 0 },
+{ "GreetFont",		"charter,16,5,0,50,0", 1 },
+{ "StdFont",		"helvetica,10,5,0,50,0", 1 },
+{ "FailFont",		"helvetica,10,5,0,75,0", 1 },
 { "AntiAliasing",	"true", 0 },
 { "NumLock",		"Off", 0 },
 { "Language",		"de_DE", 0 },
@@ -1071,7 +1073,7 @@
 static DEnt dEntsLocalCore[] = {
 { "ServerAttempts",	"", 0 },
 { "ServerTimeout",	"", 0 },
-{ "AllowShutdown",	"All", 1 },
+{ "AllowShutdown",	"Root", 1 },
 { "AllowRootLogin",	"true", 1 },
 { "AllowNullPasswd",	"true", 1 },
 { "NoPassEnable",	"true", 0 },
